@@ -10,24 +10,24 @@ from . import selector
 
 @click.group()
 @click.version_option(version=__version__)
-def main():
+def main() -> None:
     daiquiri.setup(level=logging.INFO)
 
 
 @main.command()
-@click.option('--size')
-def shuffle(size=None):
+@click.option("--size")
+def shuffle(size: str | None = None):
     wallpaper = selector.select_random_wallpaper(size)
     print(wallpaper)  # noqa
 
 
 @main.command()
-@click.option('--size')
-@click.argument('desktop', type=click.Choice(desktops.DESKTOPS))
-def gsettings(desktop=None, size=None):
-    wallpaper = desktops.set_wallpaper(desktop, size)
+@click.option("--size")
+@click.argument("desktop", type=click.Choice([x.name for x in desktops.Desktops]))
+def gsettings(desktop: str, size: str | None = None) -> None:
+    wallpaper = desktops.set_wallpaper(desktops.Desktops[desktop], size)
     logging.info("Set wallpaper to %s", wallpaper)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
